@@ -14,7 +14,16 @@ class apmd():
 
   def run(self):
     self.apm = AdvancedPowerMonitor.apm()
-    self.loop.run()
+    try:
+      self.loop.run()
+    except (KeyboardInterrupt, SystemExit):
+      self.quit()
+      raise
+
+  def quit(self, *args):
+    self.loop.quit()
+    self.apm._cleanup()
+    self.apm = None
 
 if __name__ == "__main__":
   daemon = apmd()
